==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtregionsegHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "摜̗̈؂o"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-H*/
#define HOLT "(X)W"
#define HOLC "(X)W"
#define HOLF NULL

/*-V*/
#define VERT "(Y)W"
#define VERC "(Y)W"
#define VERF NULL

/*-v*/
#define HTFT "Zpositive"
#define HTFC "Zpositive"
#define HTFF NULL

/*-s*/
#define SPFT "Ztotal"
#define SPFC "Ztotal"
#define SPFF NULL

/*-M*/
#define SPVT "total(ő̐Fl)"
#define SPVC "total(ő̐Fl)"

/*-S*/
#define SIZT "TCY(X,Y)"
#define SIZC "TCY(X,Y)"

/*-c*/
#define RTPT "̈̌`"
#define RTPC "̈̌`"
#define RTPS "XP,YP,XYP,`"

/*-n*/
#define NULT "NULL̈"
#define NULC "NULL̈"
#define NULS "PositiveƂăJEg,NegativeƂăJEg"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "񎟌}gbNẌ(XP,YP,XYP,`)؂oB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtregionseg -H X -V Y -v Red -M255 -S 100,100 -r x -i dat.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xt2ppm,ppm2xt"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre4.tar.gz: musashi-core-1.0.4-pre4/help/ja-sjis/xtregionsegHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "摜̗̈؂o"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-H*/
#define HOLT "(X)W"
#define HOLC "(X)W"
#define HOLF NULL

/*-V*/
#define VERT "(Y)W"
#define VERC "(Y)W"
#define VERF NULL

/*-v*/
#define HTFT "Zpositive"
#define HTFC "Zpositive"
#define HTFF NULL

/*-s*/
#define SPFT "Ztotal"
#define SPFC "Ztotal"
#define SPFF NULL

/*-M*/
#define SPVT "total(ő̐Fl)"
#define SPVC "total(ő̐Fl)"

/*-S*/
#define SIZT "TCY(X,Y)"
#define SIZC "TCY(X,Y)"

/*-c*/
#define RTPT "̈̌`"
#define RTPC "̈̌`"
#define RTPS "XP,YP,XYP,`"

/*-n*/
#define NULT "NULL̈"
#define NULC "NULL̈"
#define NULS "PositiveƂăJEg,NegativeƂăJEg"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "񎟌}gbNẌ(XP,YP,XYP,`)؂oB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtregionseg -H X -V Y -v Red -M255 -S 100,100 -r x -i dat.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xt2ppm,ppm2xt"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
